@@ -9,7 +9,7 @@ def condition_by_between(filters: list, model, column, start_value, end_value):
 def condition_by_in(filters: list, model, column, value):
     _filter = None
     if value and isinstance(value, list):
-        value = [_ for _ in value if _]
+        value = [_ for _ in value if _ is not None]
         _filter = getattr(model, column).in_(value)
         filters.append(_filter)
     return _filter
